﻿#region using

using System;
using System.Linq;
using System.Text.RegularExpressions;
using System.Web;

using BlogEngine.Core;
using BlogEngine.Core.Web.Controls;

using Resources;

#endregion

[Extension(
    "将 Feed 内容按照自定的模板输出",
    "1.0",
    "<a href=\"http://www.blogyi.net\">BlogYi.NET</a>",
    1010)]
public class FeedInTemplate
{
    #region Constructors and Destructors

    /// <summary>
    /// Initializes static members of the <see cref="BreakPost"/> class. 
    ///     Hooks up an event handler to the Post.Serving event.
    /// </summary>
    static FeedInTemplate()
    {
        Post.Serving += new EventHandler<ServingEventArgs>(PostServing);
    }

    #endregion

    #region Methods


    /// <summary>
    /// Handles the Serving event of the Post control.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">The <see cref="BlogEngine.Core.ServingEventArgs"/> instance containing the event data.</param>
    private static void PostServing(object sender, ServingEventArgs e)
    {
        var post = (Post)sender;

        if (string.IsNullOrEmpty(post.Description) || string.IsNullOrEmpty(post.Content))
            return;

        if (e.Location == ServingLocation.Feed)
        {            
            e.Body = FillFeedTemplate(post);
        }
    }

    public static string FillFeedTemplate(Post post)
    {
        string template = GetFeedTemplateBody();
        if (string.IsNullOrEmpty(template))
            return post.Content;

        template = template.Replace("[:description:]", post.Description);
        template = template.Replace("[:content:]", post.Content);
        template = template.Replace("[:link:]", post.AbsoluteLink.ToString());
        template = template.Replace("[:title:]", post.Title);

        return template;
    }

    public static string GetFeedTemplateBody()
    {
        const string CACHE_KEY = "GetFeedTemplateBody";
        string content = string.Empty;

        if (HttpRuntime.Cache[CACHE_KEY] != null)
        {
            content = (string)HttpRuntime.Cache[CACHE_KEY];
        }
        else
        {
            System.Collections.Generic.List<BlogEngine.Core.Page> pages =
                BlogEngine.Core.Page.Pages.FindAll(delegate(BlogEngine.Core.Page p)
                { return (p.Slug.ToLower() == "feed-template"); });
            if (pages.Count > 0)
            {
                content = pages[0].Content;
                HttpRuntime.Cache[CACHE_KEY] = content;
            }
            else
            {
                HttpRuntime.Cache.Remove(CACHE_KEY);
            }
        }

        return content;
    }

    #endregion
}